@@ -1,11 +1,19 @@
 #!/usr/bin/env perl
 #
-# Copyright (C) 2001-2022 Graeme Walker <graeme_walker@users.sourceforge.net>
-# 
-# Copying and distribution of this file, with or without modification,
-# are permitted in any medium without royalty provided the copyright
-# notice and this notice are preserved.  This file is offered as-is,
-# without any warranty.
+# Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+#
+# This program is free software: you can redistribute it and/or modify
+# it under the terms of the GNU General Public License as published by
+# the Free Software Foundation, either version 3 of the License, or
+# (at your option) any later version.
+#
+# This program is distributed in the hope that it will be useful,
+# but WITHOUT ANY WARRANTY; without even the implied warranty of
+# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
+# GNU General Public License for more details.
+#
+# You should have received a copy of the GNU General Public License
+# along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ===
 #
 # emailrelay-rot13.pl
@@ -31,7 +39,7 @@ while(<$fh_in>)
 
 	if( $in_header && ( $line =~ m/^\s/ ) && scalar(@headers) ) # folding
 	{
-		$headers[-1] .= "\r\n$line" ;
+		@headers[-1] .= "\r\n$line" ;
 	}
 	elsif( $in_header && ( $line =~ m/^$/ ) )
 	{
