@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -33,19 +33,19 @@ void G::Daemon::detach()
 {
 	// see Stevens, ISBN 0-201-563137-7, ch 13.
 
-	if( NewProcess::fork() == NewProcess::Parent )
-		::_exit( 0 ) ;
+	if( !NewProcess::fork().first )
+		::_exit( 0 ) ; // exit from parent
 
 	setsid() ;
-	G_IGNORE_RETURN(bool) Process::cd( "/" , Process::NoThrow() ) ;
+	bool rc = Process::cd( "/" , Process::NoThrow() ) ; G_IGNORE_VARIABLE(bool,rc) ;
 
-	if( NewProcess::fork() == NewProcess::Parent )
-		::_exit( 0 ) ;
+	if( !NewProcess::fork().first )
+		::_exit( 0 ) ; // exit from parent
 }
 
 void G::Daemon::setsid()
 {
-	G_IGNORE_RETURN(pid_t) ::setsid() ;
+	pid_t rc = ::setsid() ; G_IGNORE_VARIABLE(pid_t,rc) ;
 }
 
 /// \file gdaemon_unix.cpp
