@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -24,27 +24,33 @@
 #include "gdef.h"
 #include <string>
 
-/// \namespace G
 namespace G
 {
 	class Xtext ;
 }
 
 /// \class G::Xtext
-/// An xtext codec class.
-/// \see RFC1891 section 5
+/// An xtext codec class, encoding space as "+20" etc.
+/// \see RFC-1891 section 5
 ///
-class G::Xtext 
+class G::Xtext
 {
 public:
 	static std::string encode( const std::string & ) ;
 		///< Encodes the given string.
 
 	static std::string decode( const std::string & ) ;
-		///< Decodes the given string.
+		///< Decodes the given string. Input strings must be
+		///< un-strictly valid(), otherwise the result is
+		///< undefined.
+
+	static bool valid( const std::string & , bool strict = false ) ;
+		///< Returns true if a valid encoding. If strict
+		///< then 'equals' and 'space' are disallowed and
+		///< hex characters must be uppercase (eg. "+1A").
 
 private:
-	Xtext() ;
+	Xtext() g__eq_delete ;
 } ;
 
 #endif
