@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,13 +18,14 @@
 /// \file gevent.h
 ///
 
-#ifndef G_EVENT_H
-#define G_EVENT_H
+#ifndef G_NET_EVENT__H
+#define G_NET_EVENT__H
 
 #include "gdef.h"
-#include "gnet.h"
+#include "gexceptionhandler.h"
 #include "geventloop.h"
 #include "geventhandler.h"
+#include "geventhandlerlist.h"
 
 #endif
 
