@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -18,19 +18,21 @@
 /// \file gcominit.h
 ///
 
-#ifndef G_COM_INIT_H__
-#define G_COM_INIT_H__
+#ifndef G_COM_INIT_H
+#define G_COM_INIT_H
 
-#ifdef G_WIN32
-#include <windows.h>
+#include "gdef.h"
+#ifdef G_WINDOWS
 #include <objbase.h>
 struct GComInit
 {
-	GComInit() { CoInitializeEx(0,0) ; }
+	GComInit() { HRESULT h = CoInitializeEx(0,0) ; (void)h ; }
 	~GComInit() { CoUninitialize() ; }
 } ;
 #else
-struct GComInit {} ;
+struct GComInit
+{
+} ;
 #endif
 
 #endif
