@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -24,7 +24,6 @@
 #include "gdef.h"
 #include <string>
 
-/// \namespace Main
 namespace Main
 {
 	class Legal ;
@@ -33,9 +32,9 @@ namespace Main
 /// \class Main::Legal
 /// A static class providing warranty and copyright text.
 ///
-class Main::Legal 
+class Main::Legal
 {
-public: 
+public:
 	static std::string warranty( const std::string & prefix , const std::string & eol ) ;
 		///< Returns the warranty text.
 
@@ -43,7 +42,7 @@ public:
 		///< Returns the copyright text.
 
 private:
-	Legal() ;
+	Legal() g__eq_delete ;
 } ;
 
 #endif
