@@ -1,16 +1,16 @@
 //
-// Copyright (C) 2001-2013 Graeme Walker <graeme_walker@users.sourceforge.net>
-// 
+// Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+//
 // This program is free software: you can redistribute it and/or modify
 // it under the terms of the GNU General Public License as published by
 // the Free Software Foundation, either version 3 of the License, or
 // (at your option) any later version.
-// 
+//
 // This program is distributed in the hope that it will be useful,
 // but WITHOUT ANY WARRANTY; without even the implied warranty of
 // MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 // GNU General Public License for more details.
-// 
+//
 // You should have received a copy of the GNU General Public License
 // along with this program.  If not, see <http://www.gnu.org/licenses/>.
 // ===
@@ -28,6 +28,10 @@ GGui::ApplicationInstance::ApplicationInstance( HINSTANCE h )
 	hinstance( h ) ;
 }
 
+GGui::ApplicationInstance::~ApplicationInstance()
+{
+}
+
 void GGui::ApplicationInstance::hinstance( HINSTANCE h )
 {
 	if( h )
@@ -39,8 +43,4 @@ HINSTANCE GGui::ApplicationInstance::hinstance()
 	return m_hinstance ;
 }
 
-extern "C" void ggui_applicationinstance( HINSTANCE h )
-{
-	GGui::ApplicationInstance::hinstance( h ) ;
-}
 /// \file gappinst.cpp
