@@ -1,17 +1,17 @@
 #!/usr/bin/perl
 #
-# Copyright (C) 2001-2022 Graeme Walker <graeme_walker@users.sourceforge.net>
-# 
+# Copyright (C) 2001-2019 Graeme Walker <graeme_walker@users.sourceforge.net>
+#
 # This program is free software: you can redistribute it and/or modify
 # it under the terms of the GNU General Public License as published by
 # the Free Software Foundation, either version 3 of the License, or
 # (at your option) any later version.
-# 
+#
 # This program is distributed in the hope that it will be useful,
 # but WITHOUT ANY WARRANTY; without even the implied warranty of
 # MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 # GNU General Public License for more details.
-# 
+#
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 # ===
@@ -33,7 +33,7 @@ sub that
 	my ( $ok , @args ) = @_ ;
 	if( !$ok )
 	{
-		Carp::croak( "[ " . join(": ",map {my $s=$_=~s/\n/\\n/gr=~s/\r/\\r/gr;$s} grep{defined($_)} @args) . " ]" ) ;
+		Carp::croak( "[ " . join(": ",grep{defined($_)} @args) . " ]" ) ;
 	}
 }
 
@@ -68,14 +68,14 @@ sub fileNotEmpty
 sub running
 {
 	my ( $pid , $more ) = @_ ;
-	my $n = defined($pid) ? System::processIsRunning($pid) : 0 ;
-	Check::that( $n == 1 , "process not running" , $pid , $more ) ;
+	my $n = defined($pid) ? System::processIsRunning($pid) : -1 ;
+	Check::that( $n == 1 , "process [$pid] not running" , $pid , $more ) ;
 }
 
 sub notRunning
 {
 	my ( $pid , $more ) = @_ ;
-	my $n = defined($pid) ? System::processIsRunning($pid) : 0 ;
+	my $n = System::processIsRunning($pid) ;
 	Check::that( $n == 0 , "process still running" , $pid , $more ) ;
 }
 
@@ -136,7 +136,7 @@ sub processEffectiveUser
 	my ( $pid , $name ) = @_ ;
 	my $actual = System::effectiveUser($pid) ;
 	my $expected = System::uid($name) ;
-	Check::that( $actual == $expected , "wrong effective user: [$actual]!=[$expected]" ) ;
+	Check::that( $actual == $expected , "wrong real user: [$actual]!=[$expected]" ) ;
 }
 
 sub processSavedUser
@@ -144,7 +144,7 @@ sub processSavedUser
 	my ( $pid , $name ) = @_ ;
 	my $actual = System::savedUser($pid) ;
 	my $expected = System::uid($name) ;
-	Check::that( $actual == $expected , "wrong saved user: [$actual]!=[$expected]" ) ;
+	Check::that( $actual == $expected , "wrong real user: [$actual]!=[$expected]" ) ;
 }
 
 sub processRealGroup
@@ -160,15 +160,15 @@ sub processEffectiveGroup
 	my ( $pid , $name ) = @_ ;
 	my $actual = System::effectiveGroup($pid) ;
 	my $expected = System::gid($name) ;
-	Check::that( $actual == $expected , "wrong effective group: [$actual]!=[$expected]" ) ;
+	Check::that( $actual == $expected , "wrong real group: [$actual]!=[$expected]" ) ;
 }
 
 sub _fileLineCount
 {
 	my ( $path , $string ) = @_ ;
-	my $fh = new FileHandle( $path ) ;
+	my $f = new FileHandle( $path ) ;
 	my $n = 0 ;
-	while(<$fh>)
+	while( <$f> )
 	{
 		my $line = $_ ;
 		chomp $line ;
@@ -193,45 +193,34 @@ sub fileLineCountLessThan
 
 sub allFilesContain
 {
-	my ( $glob , $re , $more ) = @_ ;
+	my ( $glob , $string , $more ) = @_ ;
 	my @files = System::glob_( $glob ) ;
 	for my $file ( @files )
 	{
-		fileContains( $file , $re , $more ) ;
-	}
-}
-
-sub noFileContains
-{
-	my ( $glob , $string_or_list , $more ) = @_ ;
-	my @files = System::glob_( $glob ) ;
-	for my $file ( @files )
-	{
-		fileDoesNotContain( $file , $string_or_list , $more ) ;
+		fileContains( $file , $string , $more ) ;
 	}
 }
 
 sub fileContains
 {
-	my ( $path , $re , $more , $count ) = @_ ;
-	my $fh = new FileHandle( $path ) ;
+	my ( $path , $string , $more ) = @_ ;
+	my $f = new FileHandle( $path ) ;
 	my $n = 0 ;
-	while(<$fh>)
+	while( <$f> )
 	{
 		my $line = $_ ;
 		chomp $line ;
-		if( !defined($re) || $line =~ m/$re/ ) { $n++ }
+		if( !defined($string) || $line =~ m/$string/ ) { $n++ }
 	}
-	my $ok = defined($count) ? ($n == $count) : ($n > 0) ;
-	Check::that( $ok , "file does not contain expected string" , $path , "[$re]" , $more ) ;
+	Check::that( $n > 0 , "file does not contain expected string" , $path , "[$string]" , $more ) ;
 }
 
 sub fileContainsEither
 {
 	my ( $path , $string1 , $string2 , $more ) = @_ ;
-	my $fh = new FileHandle( $path ) ;
+	my $f = new FileHandle( $path ) ;
 	my $n = 0 ;
-	while(<$fh>)
+	while( <$f> )
 	{
 		my $line = $_ ;
 		chomp $line ;
@@ -268,3 +257,4 @@ sub match
 }
 
 1 ;
+
